// $URL: http://subversion:8080/svn/gsc/trunk/drivers/LINUX/24DSI12WRCIEPE/24DSI12WRCIEPE_linux_1.x.x.x_gsc_dn/utils/util_irq_sel.c $
// $Rev: 52535 $
// $Date: 2023-03-02 14:55:56 -0600 (Thu, 02 Mar 2023) $

// 24DSI12WRCIEPE: Utilities: source file

#include "main.h"



/******************************************************************************
*
*	Function:	dsi12wi_irq_sel
*
*	Purpose:
*
*		Provide a visual wrapper for the DSI12WI_IOCTL_IRQ_SEL service.
*
*	Arguments:
*
*		fd		Use this handle to access the device.
*
*		index	The index of the device to access. Ignore if < 0.
*				This is for display purposes only.
*
*		verbose	Work verbosely?
*
*		set		This is the value to apply.
*
*		get		The results are reported here. This may be NULL.
*
*	Returned:
*
*		>= 0	The number of errors encounterred.
*
******************************************************************************/

int dsi12wi_irq_sel(int fd, int index, int verbose, s32 set, s32* get)
{
	char		buf[128];
	int			errs;
	const char*	ptr;
	int			ret;

	if (verbose)
		gsc_label_index("IRQ Select", index);

	ret		= dsi12wi_ioctl(fd, DSI12WI_IOCTL_IRQ_SEL, &set);
	errs	= ret ? 1 : 0;

	switch (set)
	{
		default:

			errs++;
			ptr	= buf;
			sprintf(buf, "Unrecognized option: 0x%lX", (long) set);
			break;

		case DSI12WI_IRQ_INIT_DONE:

			ptr	= "Initialize Done";
			break;

		case DSI12WI_IRQ_AUTO_CAL_DONE:

			ptr	= "Auto-Calibration Done";
			break;

		case DSI12WI_IRQ_CHAN_READY:

			ptr	= "Channel Ready";
			break;

		case DSI12WI_IRQ_AI_BUF_THRESH_L2H:

			ptr	= "AI Buffer Threshold Low-to-High";
			break;

		case DSI12WI_IRQ_AI_BUF_THRESH_H2L:

			ptr	= "AI Buffer Threshold High-to-Low";
			break;
	}

	if (verbose)
		printf("%s  (%s)\n", errs ? "FAIL <---" : "PASS", ptr);

	if (get)
		get[0]	= set;

	return(errs);
}


